import logging
import base64
from proto_proto_pscr.cb_psc_nta_pb2 import NtaBatchJobRequest
from llanta_manager.utils import ScheduledWorkerThread

_logger = logging.getLogger(__name__)


class BatchJobTriggerer(ScheduledWorkerThread):
    """Trigger a batch job with a given detector id
    for each active subnet of each llanta process.
    """

    def __init__(
        self, llanta_pool, detector_id, batch_job_interval_seconds, sqs_connector
    ):
        self.llanta_pool = llanta_pool
        self.detector_id = detector_id
        self.batch_job_interval_seconds = batch_job_interval_seconds
        self.sqs_connector = sqs_connector
        super().__init__(
            job=self.trigger_batch_jobs,
            job_interval_seconds=self.batch_job_interval_seconds,
        )

    def trigger_batch_jobs(self):
        trigger_messages = [
            base64.b64encode(
                NtaBatchJobRequest(
                    **{"detector_id": self.detector_id, "license_info": subnet}
                ).SerializeToString()
            ).decode()
            for _, llanta in self.llanta_pool.items()
            for subnet in llanta.active_subnets
        ]
        if trigger_messages:
            _logger.info(
                f"Triggering batch jobs with detector id {self.detector_id} for {len(trigger_messages)} subnets"
            )
            self.sqs_connector.send_message_batch(trigger_messages)
        else:
            _logger.warning(
                f"No active subnets, skipping trigger for batch job with detector {self.detector_id}"
            )
