import os
import asyncio
from pyformance.registry import MetricsRegistry
from pscr_common.metrics import get_reporter
from pscr_common.metadata import MetadataProvider
from threading import Thread


class Metrics:

    llanta_processes_count = "llanta_manager.llanta_processes.count"
    llanta_events_rate = "llanta_manager.llanta_events.rate"
    llanta_process_cpu = "llanta_manager.llanta_process.cpu"
    llanta_process_memory = "llanta_manager.llanta_process.memory"
    llanta_failed_lookups = "llanta_manager.llanta_failed_lookups"
    llanta_purged_exited = "llanta_manager.llanta_purged_exited"
    llanta_purged_unresponsive = "llanta_manager.llanta_purged_unresponsive"
    llanta_purged_idle = "llanta_manager.llanta_purged_idle"

    def __init__(self):
        self.metrics_registry = MetricsRegistry()
        self.reporter_thread = Thread(target=self._start_reporter, daemon=True)
        self.reporter_thread.start()

    def _start_reporter(self):
        """Run the metrics reporter's loop"""
        env = os.environ.get("ENV_ID", "unknown")
        env_meta = MetadataProvider().get_metadata()
        reporter = get_reporter(
            self.metrics_registry,
            env,
            env_meta.task_id,
            "llanta_manager",
            env_meta.image.rsplit(":", maxsplit=1)[-1],
        )

        if reporter:
            asyncio.run(reporter._loop())
