import logging
from typing import List
from pscr_common.aws import get_boto3_client
_logger = logging.getLogger(__name__)

class SqsConnector:
    """Class to handle communication through SQS"""

    max_entries_per_batch = 8

    def __init__(self, queue_url):
        self.sqs = get_boto3_client("sqs")
        self.queue_url = queue_url

    def send_message(self, message: str):
        """Put a single message in the queue"""
        _logger.debug(f"Sending message to SQS: {message}")
        self.sqs.send_message(QueueUrl=self.queue_url, MessageBody=message)

    def send_message_batch(self, messages: List[str]):
        """Put a batch of messages in the queue"""
        for batch_idx in range(0, len(messages), self.max_entries_per_batch):
            # we need to further batch the messages, if they're too many due to AWS limitations
            messages_batch = [
                {"Id": f"{idx}", "MessageBody": message}
                for idx, message in enumerate(
                    messages[batch_idx : batch_idx + self.max_entries_per_batch]
                )
            ]
            _logger.debug(f"Sending message batch to SQS: {messages_batch}")
            self.sqs.send_message_batch(QueueUrl=self.queue_url, Entries=messages_batch)
